==> funki-0.0.61.tar.gz: funki-0.0.61/funki/text_colours.py <==
BOLD    = "\033[;1m"
REVERSE = "\033[;7m"
RESET   = "\033[0;0m"

# Foreground Colours
RED     = "\033[0;31m"
GREEN   = "\033[0;32m"
YELLOW  = "\033[0;33m"
BLUE    = "\033[0;34m"
MAGENTA = "\033[0;35m"
CYAN    = "\033[0;36m"
WHITE   = "\033[0;37m"
DEFAULT = "\033[0;39m"

red     = lambda μ:     f'{RED}{μ}{RESET}'
green   = lambda μ:   f'{GREEN}{μ}{RESET}'
yellow  = lambda μ:  f'{YELLOW}{μ}{RESET}'
blue    = lambda μ:    f'{BLUE}{μ}{RESET}'
magenta = lambda μ: f'{MAGENTA}{μ}{RESET}'
cyan    = lambda μ:    f'{CYAN}{μ}{RESET}'
white   = lambda μ:   f'{WHITE}{μ}{RESET}'
default = lambda μ: f'{DEFAULT}{μ}{RESET}'

# Bright Foreground Colours
BRIGHT_RED     = "\033[1;31m"
BRIGHT_GREEN   = "\033[1;32m"
BRIGHT_YELLOW  = "\033[1;33m"
BRIGHT_BLUE    = "\033[1;34m"
BRIGHT_MAGENTA = "\033[1;35m"
BRIGHT_CYAN    = "\033[1;36m"
BRIGHT_WHITE   = "\033[1;37m"

bright_red     = lambda μ:     f'{BRIGHT_RED}{μ}{RESET}'
bright_green   = lambda μ:   f'{BRIGHT_GREEN}{μ}{RESET}'
bright_yellow  = lambda μ:  f'{BRIGHT_YELLOW}{μ}{RESET}'
bright_blue    = lambda μ:    f'{BRIGHT_BLUE}{μ}{RESET}'
bright_magenta = lambda μ: f'{BRIGHT_MAGENTA}{μ}{RESET}'
bright_cyan    = lambda μ:    f'{BRIGHT_CYAN}{μ}{RESET}'
bright_white   = lambda μ:   f'{BRIGHT_WHITE}{μ}{RESET}'

danger    = lambda μ:  bright_red(μ)
info      = lambda μ: bright_cyan(μ)
primary   = lambda μ:        blue(μ)
secondary = lambda μ:     magenta(μ)
success   = lambda μ:       green(μ)
warning   = lambda μ:      yellow(μ)

danger_if_zero = lambda z: f'{z:3d}' if z else danger(f'{z:3d}')
get_categories = lambda: [danger, warning, success, primary, info]
tgfr           = lambda b: (success if b else danger)(f'{str(b):5}')

def rainbow_test(μ):
  for (name, fn) in [
    ('red', red),
    ('green', green),
    ('yellow', yellow),
    ('blue', blue),
    ('magenta', magenta),
    ('cyan', cyan),
    ('white', white),
    ('default', default),
    ('bright_red', bright_red),
    ('bright_yellow', bright_yellow),
    ('bright_green', bright_green),
    ('bright_cyan', bright_cyan),
    ('bright_blue', bright_blue),
    ('bright_magenta', bright_magenta),
    ('bright_white', bright_white),
  ]:
    print(f'{name}: {fn(μ)}')

==> funki-0.0.70.tar.gz: funki-0.0.70/funki/text_colours.py <==
BOLD    = "\033[;1m"
REVERSE = "\033[;7m"
RESET   = "\033[0;0m"

# Foreground Colours
RED     = "\033[0;31m"
GREEN   = "\033[0;32m"
YELLOW  = "\033[0;33m"
BLUE    = "\033[0;34m"
MAGENTA = "\033[0;35m"
CYAN    = "\033[0;36m"
WHITE   = "\033[0;37m"
DEFAULT = "\033[0;39m"

red     = lambda μ:     f'{RED}{μ}{RESET}'
green   = lambda μ:   f'{GREEN}{μ}{RESET}'
yellow  = lambda μ:  f'{YELLOW}{μ}{RESET}'
blue    = lambda μ:    f'{BLUE}{μ}{RESET}'
magenta = lambda μ: f'{MAGENTA}{μ}{RESET}'
cyan    = lambda μ:    f'{CYAN}{μ}{RESET}'
white   = lambda μ:   f'{WHITE}{μ}{RESET}'
default = lambda μ: f'{DEFAULT}{μ}{RESET}'

# Bright Foreground Colours
BRIGHT_RED     = "\033[1;31m"
BRIGHT_GREEN   = "\033[1;32m"
BRIGHT_YELLOW  = "\033[1;33m"
BRIGHT_BLUE    = "\033[1;34m"
BRIGHT_MAGENTA = "\033[1;35m"
BRIGHT_CYAN    = "\033[1;36m"
BRIGHT_WHITE   = "\033[1;37m"

bright_red     = lambda μ:     f'{BRIGHT_RED}{μ}{RESET}'
bright_green   = lambda μ:   f'{BRIGHT_GREEN}{μ}{RESET}'
bright_yellow  = lambda μ:  f'{BRIGHT_YELLOW}{μ}{RESET}'
bright_blue    = lambda μ:    f'{BRIGHT_BLUE}{μ}{RESET}'
bright_magenta = lambda μ: f'{BRIGHT_MAGENTA}{μ}{RESET}'
bright_cyan    = lambda μ:    f'{BRIGHT_CYAN}{μ}{RESET}'
bright_white   = lambda μ:   f'{BRIGHT_WHITE}{μ}{RESET}'

danger    = lambda μ:   bright_red(μ)
info      = lambda μ:  bright_cyan(μ)
primary   = lambda μ:         blue(μ)
secondary = lambda μ:      magenta(μ)
success   = lambda μ: bright_green(μ)
warning   = lambda μ:       yellow(μ)

danger_if_zero = lambda z: f'{z:3d}' if z else danger(f'{z:3d}')
get_categories = lambda: [danger, warning, success, primary, info]
tgfr           = lambda b: (success if b else danger)(f'{str(b):5}')

def rainbow_test(μ):
  for (name, fn) in [
    ('red', red),
    ('green', green),
    ('yellow', yellow),
    ('blue', blue),
    ('magenta', magenta),
    ('cyan', cyan),
    ('white', white),
    ('default', default),
    ('bright_red', bright_red),
    ('bright_yellow', bright_yellow),
    ('bright_green', bright_green),
    ('bright_cyan', bright_cyan),
    ('bright_blue', bright_blue),
    ('bright_magenta', bright_magenta),
    ('bright_white', bright_white),
  ]:
    print(f'{name}: {fn(μ)}')
